@@ -450,7 +450,7 @@ class PulsarReactiveClientModuleTest {
 	}
 
 	@ParameterizedTest
-	@ValueSource(strings = { "parallel", "elastic", "boundedElastic", "immediate", "single" })
+	@ValueSource(strings = { "parallel", "boundedElastic", "immediate", "single" })
 	void shouldSerDeserScheduler(String scheduler) throws Exception {
 		String content = (String.format("\"%s\"", scheduler));
 		Scheduler policy = MAPPER.readValue(content, Scheduler.class);
@@ -458,6 +458,13 @@ class PulsarReactiveClientModuleTest {
 		assertThat(json).isEqualTo(content);
 	}
 
+	@Test
+	void shouldSerDeserDeprecatedElasticScheduler() throws Exception {
+		Scheduler policy = MAPPER.readValue("\"elastic\"", Scheduler.class);
+		String json = MAPPER.writeValueAsString(policy);
+		assertThat(json).isEqualTo("\"boundedElastic\"");
+	}
+
 	@Test
 	void shouldSerializeCustomScheduler() throws Exception {
 		String json = MAPPER.writeValueAsString(new TestScheduler());
